@@ -1,14 +1,72 @@
 package WWW::Mechanize::Link;
-
+$WWW::Mechanize::Link::VERSION = '1.78';
 use strict;
 use warnings;
 
-our $VERSION = '1.75';
+#ABSTRACT: Link object for WWW::Mechanize
+
+
+sub new {
+    my $class = shift;
+
+    my $self;
+
+    # The order of the first four must stay as they are for
+    # compatibility with older code.
+    if ( ref $_[0] eq 'HASH' ) {
+        $self = [ @{$_[0]}{ qw( url text name tag base attrs ) } ];
+    }
+    else {
+        $self = [ @_ ];
+    }
+
+    return bless $self, $class;
+}
+
+
+sub url   { return ($_[0])->[0]; }
+sub text  { return ($_[0])->[1]; }
+sub name  { return ($_[0])->[2]; }
+sub tag   { return ($_[0])->[3]; }
+sub base  { return ($_[0])->[4]; }
+sub attrs { return ($_[0])->[5]; }
+
+
+sub URI {
+    my $self = shift;
+
+    require URI::URL;
+    my $URI = URI::URL->new( $self->url, $self->base );
+
+    return $URI;
+}
+
+
+sub url_abs {
+    my $self = shift;
+
+    return $self->URI->abs;
+}
+
+
+# vi:et:sw=4 ts=4
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 WWW::Mechanize::Link - Link object for WWW::Mechanize
 
+=head1 VERSION
+
+version 1.78
+
 =head1 SYNOPSIS
 
 Link object to encapsulate all the stuff that Mech needs but nobody
@@ -33,25 +91,6 @@ For compatibility, this older interface is also supported:
 
 Creates and returns a new C<WWW::Mechanize::Link> object.
 
-=cut
-
-sub new {
-    my $class = shift;
-
-    my $self;
-
-    # The order of the first four must stay as they are for
-    # compatibility with older code.
-    if ( ref $_[0] eq 'HASH' ) {
-        $self = [ @{$_[0]}{ qw( url text name tag base attrs ) } ];
-    }
-    else {
-        $self = [ @_ ];
-    }
-
-    return bless $self, $class;
-}
-
 =head1 Accessors
 
 =head2 $link->url()
@@ -78,65 +117,27 @@ Base URL to which the links are relative.
 
 Returns hash ref of all the attributes and attribute values in the tag. 
 
-=cut
-
-sub url   { return ($_[0])->[0]; }
-sub text  { return ($_[0])->[1]; }
-sub name  { return ($_[0])->[2]; }
-sub tag   { return ($_[0])->[3]; }
-sub base  { return ($_[0])->[4]; }
-sub attrs { return ($_[0])->[5]; }
-
 =head2 $link->URI()
 
 Returns the URL as a L<URI::URL> object.
 
-=cut
-
-sub URI {
-    my $self = shift;
-
-    require URI::URL;
-    my $URI = URI::URL->new( $self->url, $self->base );
-
-    return $URI;
-}
-
 =head2 $link->url_abs()
 
 Returns a L<URI::URL> object for the absolute form of the string.
 
-=cut
-
-sub url_abs {
-    my $self = shift;
-
-    return $self->URI->abs;
-}
-
 =head1 SEE ALSO
 
 L<WWW::Mechanize> and L<WWW::Mechanize::Image>
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2004-2010 Andy Lester.
+Andy Lester <andy at petdance.com>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of either:
+=head1 COPYRIGHT AND LICENSE
 
-=over 4
+This software is copyright (c) 2004-2016 by Andy Lester.
 
-=item * the GNU General Public License as published by the Free
-Software Foundation; either version 1, or (at your option) any later
-version, or
-
-=item * the Artistic License version 2.0.
-
-=back
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-# vi:et:sw=4 ts=4
-
-1;
